--[[
## Interface: 30100
## Title: Mini-Targ |cffcc00cc 3.3 RC|r
## Author: Tearstar, GM of The Stellar Guard of Baelgun US <tear_star@yahoo.com> based on code from CHiLLZ at Chillz Media.
## Version: 3.3
## X-Revision: 1000
## Notes: Shows a 3D model of your target in a movable frame, with interactive camera viewing, also comes with some Target Information, will soon have more features.
## License: Copyright 2008-2009, Online Gaming Experience. All rights reserved.
]]--

-- SETTINGS --
local MT_Title = "Mini-Targ"
local MT_Version = 3.3;
local MT_Debug = false;

local MT_Defaults = {
	["Version"] = MT_Version,
	["Options"] = {
		["MT_Target"] = "true",
		["MT_Block1"] = "false",
		["MT_Block2"] = "false",
	},
}

-- FUNCTIONS --
function MT_OnLoad()
	MT:RegisterForDrag("LeftButton");
	MT:RegisterEvent("ADDON_LOADED");
	MT:RegisterEvent("PLAYER_REGEN_DISABLED");
	MT:RegisterEvent("PLAYER_REGEN_ENABLED");
	MT:RegisterEvent("PLAYER_ENTER_COMBAT");
	MT:RegisterEvent("PLAYER_LEAVE_COMBAT");	
	MT:RegisterEvent("PLAYER_ENTERING_WORLD");
	MT:RegisterEvent("PLAYER_XP_UPDATE");
	MT:RegisterEvent("PLAYER_LEVEL_UP");
	MT:RegisterEvent("PLAYER_PVP_KILLS_CHANGED");
	MT:RegisterEvent("PLAYER_TARGET_CHANGED");
	MT:RegisterEvent("UNIT_HEALTH");
	MT:RegisterEvent("UNIT_MANA");

end

function MT_OnEvent()
	if ((event == "ADDON_LOADED") and (arg1 == MT_Title)) then
		MT_Loader();
	end
	
	if (event == "PLAYER_REGEN_DISABLED"
		or "PLAYER_REGEN_ENABLED"
		or "PLAYER_ENTER_COMBAT"
		or "PLAYER_LEAVE_COMBAT"
		or "PLAYER_TARGET_CHANGED"
		or "PLAYER_PVP_KILLS_CHANGED"
	) then
		if(UnitExists("target")) then 
			MT_OnShow();
			MT_SetGuild();
		else
			MT_OnHide();
		end
	end

	if ((event == "UNIT_HEALTH") and (arg1 == "target")) then
		MT_TargetInfo();
	end
	if ((event == "UNIT_MANA") and (arg1 == "target")) then
		MT_TargetInfo();
	end


end


function MT_SetGuild()
	local guildName;
	local title;
	local rank;
	guildName, title, rank = GetGuildInfo("target");
	if ( guildName ) then
		MT_Guild:SetText( ""..title.." of "..guildName.." Guild " );
	else

		MT_Guild:SetText();
	end
end

function MTC_Toggle()
		if(MT_Target:SetCamera(1)) then 
			MT_Target:SetCamera(0);
		else
			MT_Target:SetCamera(1);
		end
end

function MT_OnShow()
	MT:Show();
	if (MT_Config["Options"]["MT_Target"] == "false") then MT_Target:Hide(); else MT_Target:Show(); end
	MT_Target:SetAlpha(2.0);
	MT_TargetName:SetAlpha(2.0);
	MT_Target:SetUnit("target");
	MT_Target:SetScale(0.7);
	MT_Target:SetPosition(0,0,0);
	
	MT_TargetInfo();
	--MT_UpdatePVP();
	
	if (MT_Debug) then
		MT_DebugInfo:SetText("Debugging display enabled.");
	end
end

function MT_OnHide()
	MT:Hide();
	MT_Casting:SetText();
	MT_Target:SetAlpha(0.0);
	MT_TargetName:SetAlpha(0.0);
end

function MT_DebugOut()
	if (MT_Debug and MT_Config["Options"]) then
		DEFAULT_CHAT_FRAME:AddMessage( "<Mini-Targ>: \(debug\)" );
		DEFAULT_CHAT_FRAME:AddMessage( "     MT_Target = "..MT_Config["Options"]["MT_Target"] );
		DEFAULT_CHAT_FRAME:AddMessage( "     MT_Block1 = "..MT_Config["Options"]["MT_Block1"] );
		DEFAULT_CHAT_FRAME:AddMessage( "     MT_Block2 = "..MT_Config["Options"]["MT_Block2"] );
		MT_Rotation:SetText( "["..rotation.."]" );
	end
end

--function CharacterModelFrame_OnMouseUp (self, button)
	--if ( button == "LeftButton" ) then
		--AutoEquipCursorItem();
	--end
--end


function MT_Loader()
	-- reset the data file?
	if (not MT_Config) then
		MT_Config = MT_Defaults;
		DEFAULT_CHAT_FRAME:AddMessage( "Mini-Targ v"..MT_Version.." initialized!  By Tearstar of Baelgun" );
	elseif (not MT_Config["Version"]) then
		MT_Config = MT_Defaults;
		DEFAULT_CHAT_FRAME:AddMessage( "Mini-Targ v"..MT_Version.." upgraded!  By Tearstar of Baelgun" );
	elseif (MT_Version > MT_Config["Version"]) then
		MT_Config = MT_Defaults;
		DEFAULT_CHAT_FRAME:AddMessage( "Mini-Targ v"..MT_Version.." upgraded.  By Tearstar of Baelgun" );
	else
		DEFAULT_CHAT_FRAME:AddMessage( "Mini-Targ v"..MT_Version.." loaded.  By Tearstar of Baelgun" );
	end
	
	-- start the mod
	MT_Settings();
end

function MT_Settings()
	if (MT_Config["Options"]["MT_Target"] == "false") then MT_Target:Hide(); else MT_Target:Show(); end
	if (MT_Config["Options"]["MT_Block1"] == "false") then MT_Block1:Hide(); else MT_Block1:Hide(); end
	if (MT_Config["Options"]["MT_Block2"] == "false") then MT_Block2:Hide(); else MT_Block2:Hide(); end

	MT_DebugOut();
end

function MT_Toggle( element )
	if ( getglobal(element):IsVisible() ) then
		-- save setting
		MT_Config["Options"][element] = "false";
		-- apply the change
		getglobal(element):Hide();
		PlaySound("gsTitleOptionOK");
	else 
		-- save setting
		MT_Config["Options"][element] = "true";
		-- apply the change
		getglobal(element):Show();
		PlaySound("gsTitleOptionOK");
	end
	MT_DebugOut();
end

function MT_RotateLeft()
	local currentFacing = MT_Target:GetFacing();
	local rotationIncrement = 0.2
		MT_Target:SetFacing(currentFacing+rotationIncrement);
		PlaySound("gsTitleOptionOK");
end

function MT_RotateRight()
	local currentFacing = MT_Target:GetFacing();
	local rotationIncrement = -0.2
		MT_Target:SetFacing(currentFacing+rotationIncrement);
		PlaySound("gsTitleOptionOK");
end



function MT_TargetInfo()
	pvpName = UnitPVPName("target");
	MT_Level:SetText( "["..UnitLevel("target").."]" );
	MT_Health:SetText( "["..UnitHealth("target").."/"..UnitHealthMax("target").."]" );
	MT_Mana:SetText( "["..UnitMana("target").."/"..UnitManaMax("target").."]" );
	local creatureType = UnitCreatureType("target");
		if (creatureType) then
			--MT_Creature:SetText( "["..creatureType.."]" );
		end

	local targetFaction = UnitFactionGroup("target");
		if (targetFaction) then
			--MT_Main:SetTexture("Interface\\TargetingFrame\\UI-PVP-"..faction);
		end

		if (UnitIsPlayer("target")) then
			local targetClass = UnitClass("target");
			local targetRace = UnitRace("target");
			MT_Class:SetText( "["..targetRace.."]["..targetClass.."]" ); 
		else
			MT_Class:SetText();
		end

		if ( UnitClassification("target") == "normal" ) then
			MT_Type:SetText();
		else
			MT_Type:SetText( "["..UnitClassification("target").."]" );
		end


		if (UnitIsPVP("target")) then
			MT_PvP:SetText( "--PvP--" );
			MT_Name:SetText(pvpName);

		else
			MT_PvP:SetText();
			MT_Name:SetText( UnitName("target") );
		end


			if (UnitIsFriend("player","target")) then 
				MT_Name:SetVertexColor(0, 1, 0);
				MT_Level:SetVertexColor(0, 1, 0);
				MT_Health:SetVertexColor(0, 1, 0);
				MT_Mana:SetVertexColor(0, 1, 0);
				MT_Class:SetVertexColor(0, 1, 0);
				MT_Type:SetVertexColor(0, 1, 0);
				MT_PvP:SetVertexColor(0, 1, 0);
			elseif (UnitIsEnemy("player","target")) then
				MT_Name:SetVertexColor(1, 0, 0);
				MT_Level:SetVertexColor(1, 0, 0);
				MT_Health:SetVertexColor(1, 0, 0);
				MT_Mana:SetVertexColor(1, 0, 0);
				MT_Class:SetVertexColor(1, 0, 0);
				MT_Type:SetVertexColor(1, 0, 0);
				MT_PvP:SetVertexColor(1, 0, 0);
			else
				MT_Name:SetVertexColor(1, 1, 0);
				MT_Level:SetVertexColor(1, 1, 0);
				MT_Health:SetVertexColor(1, 1, 0);
				MT_Mana:SetVertexColor(1, 1, 0);
				MT_Class:SetVertexColor(1, 1, 0);
				MT_Type:SetVertexColor(1, 1, 0);
				MT_PvP:SetVertexColor(1, 1, 0);
			end




end

function MT_GetBags()
	local used,total,free;
	used = 0;
	total = 0;
	free = 0;
	
	for i = 0,4 do
		local u,t = MT_GetSlots(i);
		used = used + u;
		total = total + t;
	end
	free = total - used;

	if (free < 2) then 
		MT_BagSpace:SetVertexColor(1, 0, 0);
		MT_BagIcon:SetTexture("Interface\\Icons\\INV_Misc_Bag_10_Red");
	elseif (free < 3) then
		MT_BagSpace:SetVertexColor(1, 0.5, 0);
		MT_BagIcon:SetTexture("Interface\\Icons\\INV_Misc_Bag_10");
	elseif (free < 5) then
		MT_BagSpace:SetVertexColor(1, 1, 0);
		MT_BagIcon:SetTexture("Interface\\Icons\\INV_Misc_Bag_10");
	elseif (free < 9) then
		MT_BagSpace:SetVertexColor(0, 1, 0);
		MT_BagIcon:SetTexture("Interface\\Icons\\INV_Misc_Bag_10");
	else 
		MT_BagSpace:SetVertexColor(1, 1, 1);
		MT_BagIcon:SetTexture("Interface\\Icons\\INV_Misc_Bag_10");
	end
	
	MT_BagSpace:SetText( free.."/"..total.." free");
end

function MT_GetSlots(bag)
	local numUsed, numSlots = 0, GetContainerNumSlots(bag);
	for i = 1,numSlots do
		if ( GetContainerItemLink(bag, i) ) then
			numUsed = numUsed + 1;
		end
	end
	return numUsed, numSlots;
end

function MT_Durability()
	local gearslots, cur, max, current, maximum, percent;
	local broken = false;
	current = 0;
	maximum = 0;
	percent = 0;
	
	gearslots = {"HeadSlot","ShoulderSlot","ChestSlot","WristSlot","HandsSlot","WaistSlot","LegsSlot","FeetSlot","MainHandSlot","SecondaryHandSlot","RangedSlot"};
	
	-- check each slot
	for i=1,11 do
		-- get info for each equipped item
		cur, max = MT_ItemDur(gearslots[i]); 
		
		-- only add if item has durability
		if (max) then
			-- is item broken?
			if (cur < 1) then
				broken = true;
			end
			
			-- append to totals
			current = current + cur; 
			maximum = maximum + max;
		end
	end
	
	-- calculate percentage
	if (maximum > 0) then
		percent = ( current / maximum ) * 100;
	else
		percent = 100;
	end
	
	-- colored text
	if (broken) then
		MT_Armor:SetVertexColor(1, 0, 0);
	elseif (percent < 21) then
		MT_Armor:SetVertexColor(1, 0, 0);
	elseif (percent < 41) then
		MT_Armor:SetVertexColor(1, 0.5, 0);
	elseif (percent < 61) then
		MT_Armor:SetVertexColor(1, 1, 0);
	elseif (percent < 81) then
		MT_Armor:SetVertexColor(0, 1, 0);
	else
		MT_Armor:SetVertexColor(1, 1, 1);
	end
	
	-- output
	percent = format("%.1f", percent);
	--MT_Armor:SetText(percent.."%  \("..current.."/"..maximum.."\)");
	MT_Armor:SetText(percent.."%");
end

function MT_ItemDur( index )
	MT_TT:SetOwner(WorldFrame, "ANCHOR_NONE");
	local id, hasItem, repairCost, current, maximum;
	
	id = GetInventorySlotInfo( index );
	hasItem, _, repairCost = MT_TT:SetInventoryItem("target", id);
	
	-- scan the item desc
	if (hasItem) then
		for i = 1,30 do
			local row = getglobal("MT_TTTextLeft" .. i);
			if (row) then
				local text = row:GetText();
				if (text) then
					-- search for durability string
					local _, _, cur, max = string.find(text, "Durability (%d+) / (%d+)");
					
					-- convert text to numeric
					if (cur) then
						current = tonumber(cur);
						maximum = tonumber(max);
					end
				end
			end
		end
	end
	
	return current, maximum;
end

function MT_UpdatePVP()
	local hk_lifetime, hk_today;
	
	hk_lifetime = GetPVPLifetimeStats();
	hk_today = GetPVPSessionStats();
	if (hk_today > 0) then
		MT_Kills:SetVertexColor(1, 1, 1);
	end
	
	MT_Kills:SetText(hk_lifetime.." \("..hk_today.." today\)");
end
